MedPortalClient
===============

.. currentmodule:: ontoportal_client.api

.. autoclass:: MedPortalClient
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~MedPortalClient.name

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
